@@ -6,6 +6,7 @@
 # the enclosed file COPYING for license information (GPL). If you
 # did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
 # --
+## nofilter(TidyAll::Plugin::Znuny::Perl::CacheCleanup)
 
 package Kernel::System::UnitTest::Helper;
 
@@ -112,13 +113,21 @@ sub new {
         $Self->{RestoreDatabase} = 1;
         my $StartedTransaction = $Self->BeginWork();
         $Self->{UnitTestDriverObject}->True( $StartedTransaction, 'Started database transaction.' );
-
     }
 
+    # Disable scheduling of asynchronous tasks using C<AsynchronousExecutor> component of System daemon.
     if ( $Param{DisableAsyncCalls} ) {
         $Self->DisableAsyncCalls();
     }
 
+    $Self->_DisableDefaultSysConfigSettings();
+
+    if ( $Param{DisableSysConfigs} ) {
+        $Self->DisableSysConfigs(
+            %Param
+        );
+    }
+
     return $Self;
 }
 
@@ -131,6 +140,12 @@ It is guaranteed that within a test this function will never return a duplicate.
 Please note that these numbers are not really random and should only be used
 to create test data.
 
+    my $RandomID = $HelperObject->GetRandomID();
+
+Returns:
+
+    my $RandomID = 'test2735808026700610';
+
 =cut
 
 sub GetRandomID {
@@ -148,6 +163,12 @@ It is guaranteed that within a test this function will never return a duplicate.
 Please note that these numbers are not really random and should only be used
 to create test data.
 
+    my $RandomNumber = $HelperObject->GetRandomNumber();
+
+Returns:
+
+    my $RandomNumber = '2735808026700610';
+
 =cut
 
 # Use package variables here (instead of attributes in $Self)
@@ -172,10 +193,26 @@ the login name of the new user, the password is the same.
 
     my $TestUserLogin = $HelperObject->TestUserCreate(
         Groups    => ['admin', 'users'],         # optional, list of groups to add this user to (rw rights)
-        Language  => 'de'                        # optional, defaults to 'en' if not set
+        Language  => 'de',                       # optional, defaults to 'en' if not set
         KeepValid => 1,                          # optional, defaults to 0
     );
 
+Returns:
+
+    my $TestUserLogin = 'test2755008034702000';
+
+
+To get UserLogin and UserID:
+
+    my ( $TestUserLogin, $TestUserID ) = $HelperObject->TestUserCreate(
+        Groups    => ['admin', 'users'],
+        Language  => 'de',
+        KeepValid => 1,
+    );
+
+    my $TestUserLogin = 'test2755008034702000';
+    my $TestUserID    = '123';
+
 =cut
 
 sub TestUserCreate {
@@ -256,11 +293,15 @@ creates a test customer user that can be used in tests. It will
 be set to invalid automatically during L</DESTROY()>. Returns
 the login name of the new customer user, the password is the same.
 
-    my $TestUserLogin = $HelperObject->TestCustomerUserCreate(
+    my $TestCustomerUserLogin = $HelperObject->TestCustomerUserCreate(
         Language  => 'de',   # optional, defaults to 'en' if not set
         KeepValid => 1,      # optional, defaults to 0
     );
 
+Returns:
+
+    my $TestCustomerUserLogin = 'test2735808026700610';
+
 =cut
 
 sub TestCustomerUserCreate {
@@ -313,10 +354,10 @@ sub TestCustomerUserCreate {
 
 =head2 BeginWork()
 
-    $HelperObject->BeginWork()
-
 Starts a database transaction (in order to isolate the test from the static database).
 
+    $HelperObject->BeginWork();
+
 =cut
 
 sub BeginWork {
@@ -328,10 +369,10 @@ sub BeginWork {
 
 =head2 Rollback()
 
-    $HelperObject->Rollback()
-
 Rolls back the current database transaction.
 
+    $HelperObject->Rollback();
+
 =cut
 
 sub Rollback {
@@ -347,7 +388,12 @@ sub Rollback {
 
 =head2 GetTestHTTPHostname()
 
-returns a host name for HTTP based tests, possibly including the port.
+Returns a host name for HTTP based tests, possibly including the port.
+
+    my $Hostname = $HelperObject->GetTestHTTPHostname();
+
+Returns:
+    my $Hostname = 'localhost';
 
 =cut
 
@@ -388,12 +434,19 @@ the current system time will be used.
 All calls to methods of Kernel::System::Time and Kernel::System::DateTime will
 use the given time afterwards.
 
-    $HelperObject->FixedTimeSet(366475757);         # with Timestamp
-    $HelperObject->FixedTimeSet($DateTimeObject);   # with previously created DateTime object
-    $HelperObject->FixedTimeSet();                  # set to current date and time
+    # with Timestamp
+    my $Timestamp = $HelperObject->FixedTimeSet(366475757);
+
+    # with previously created DateTime object
+    my $Timestamp = $HelperObject->FixedTimeSet($DateTimeObject);
+
+    # set to current date and time
+    my $Timestamp = $HelperObject->FixedTimeSet();
 
 Returns:
-    Timestamp
+
+    # date/time as seconds
+    my $Timestamp = 1454420017;
 
 =cut
 
@@ -412,7 +465,9 @@ sub FixedTimeSet {
 
 =head2 FixedTimeUnset()
 
-restores the regular system time behavior.
+Restores the regular system time behavior.
+
+    $HelperObject->FixedTimeUnset();
 
 =cut
 
@@ -425,9 +480,11 @@ sub FixedTimeUnset {
 
 =head2 FixedTimeAddSeconds()
 
-adds a number of seconds to the fixed system time which was previously
+Adds a number of seconds to the fixed system time which was previously
 set by FixedTimeSet(). You can pass a negative value to go back in time.
 
+    $HelperObject->FixedTimeAddSeconds(5);
+
 =cut
 
 sub FixedTimeAddSeconds {
@@ -439,9 +496,8 @@ sub FixedTimeAddSeconds {
 }
 
 # See http://perldoc.perl.org/5.10.0/perlsub.html#Overriding-Built-in-Functions
-## nofilter(TidyAll::Plugin::OTRS::Perl::Time)
-## nofilter(TidyAll::Plugin::OTRS::Migrations::OTRS6::TimeObject)
-## nofilter(TidyAll::Plugin::OTRS::Migrations::OTRS6::DateTime)
+## nofilter(TidyAll::Plugin::Znuny::Perl::Time)
+
 sub _MockPerlTimeHandling {
     no warnings 'redefine';    ## no critic
     *CORE::GLOBAL::time = sub {
@@ -492,7 +548,7 @@ sub _MockPerlTimeHandling {
         if ( $INC{$FilePath} ) {
             no warnings 'redefine';    ## no critic
             delete $INC{$FilePath};
-            require $FilePath;         ## nofilter(TidyAll::Plugin::OTRS::Perl::Require)
+            require $FilePath;         ## nofilter(TidyAll::Plugin::Znuny::Perl::Require)
         }
     }
 
@@ -688,6 +744,9 @@ Please note that this will not work correctly in clustered environments.
 sub ConfigSettingChange {
     my ( $Self, %Param ) = @_;
 
+    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
+    my $MainObject   = $Kernel::OM->Get('Kernel::System::Main');
+
     my $Valid = $Param{Valid} // 1;
     my $Key   = $Param{Key};
     my $Value = $Param{Value};
@@ -702,14 +761,14 @@ sub ConfigSettingChange {
     $KeyDump =~ s|\#{3}|'}->{'|smxg;
 
     # Also set at runtime in the ConfigObject. This will be destroyed at the end of the unit test.
-    $Kernel::OM->Get('Kernel::Config')->Set(
+    $ConfigObject->Set(
         Key   => $Key,
         Value => $Valid ? $Value : undef,
     );
 
     my $ValueDump;
     if ($Valid) {
-        $ValueDump = $Kernel::OM->Get('Kernel::System::Main')->Dump($Value);
+        $ValueDump = $MainObject->Dump($Value);
         $ValueDump =~ s/\$VAR1/$KeyDump/;
     }
     else {
@@ -732,9 +791,11 @@ sub Load {
 }
 1;
 EOF
-    my $Home     = $Kernel::OM->Get('Kernel::Config')->Get('Home');
+
+    my $Home     = $ConfigObject->Get('Home');
     my $FileName = "$Home/Kernel/Config/Files/$PackageName.pm";
-    $Kernel::OM->Get('Kernel::System::Main')->FileWrite(
+
+    $MainObject->FileWrite(
         Location => $FileName,
         Mode     => 'utf8',
         Content  => \$Content,
@@ -798,7 +859,9 @@ sub CustomCodeActivate {
 
 =head2 CustomFileCleanup()
 
-Remove all custom files from C<ConfigSettingChange()> and C<CustomCodeActivate()>.
+Removes all custom files from C<ConfigSettingChange()> and C<CustomCodeActivate()>.
+
+    $HelperObject->CustomFileCleanup();
 
 =cut
 
@@ -820,7 +883,9 @@ sub CustomFileCleanup {
 
 =head2 UseTmpArticleDir()
 
-switch the article storage directory to a temporary one to prevent collisions;
+Switch the article storage directory to a temporary one to prevent collisions;
+
+    $HelperObject->UseTmpArticleDir();
 
 =cut
 
@@ -852,7 +917,9 @@ sub UseTmpArticleDir {
 
 =head2 DisableAsyncCalls()
 
-Disable scheduling of asynchronous tasks using C<AsynchronousExecutor> component of OTRS daemon.
+Disable scheduling of asynchronous tasks using C<AsynchronousExecutor> component of System daemon.
+
+    $HelperObject->DisableAsyncCalls();
 
 =cut
 
@@ -868,6 +935,76 @@ sub DisableAsyncCalls {
     return 1;
 }
 
+=head2 _DisableDefaultSysConfigSettings()
+
+These SysConfig options are disabled by default.
+
+=cut
+
+sub _DisableDefaultSysConfigSettings {
+    my ( $Self, %Param ) = @_;
+
+    my @DisableSysConfigs = (
+        'Ticket::EventModulePost###999-NotifyOnEmptyProcessTickets',
+        'Ticket::EventModulePost###Mentions',
+    );
+
+    $Self->DisableSysConfigs(
+        DisableSysConfigs => \@DisableSysConfigs,
+    );
+
+    return 1;
+}
+
+=head2 DisableSysConfigs()
+
+Disables SysConfigs for current UnitTest.
+
+    $HelperObject->DisableSysConfigs(
+        DisableSysConfigs => [
+            'Ticket::Responsible'
+            'DashboardBackend###0442-RSS'
+        ],
+    );
+
+    $Kernel::OM->ObjectParamAdd(
+        'Kernel::System::UnitTest::Helper' => {
+            DisableSysConfigs => [
+                'Ticket::Responsible'
+                'DashboardBackend###0442-RSS'
+            ],
+        },
+    );
+
+=cut
+
+sub DisableSysConfigs {
+    my ( $Self, %Param ) = @_;
+
+    my $LogObject = $Kernel::OM->Get('Kernel::System::Log');
+
+    NEEDED:
+    for my $Needed (qw(DisableSysConfigs)) {
+
+        next NEEDED if defined $Param{$Needed};
+
+        $LogObject->Log(
+            Priority => 'error',
+            Message  => "Parameter '$Needed' is needed!",
+        );
+        return;
+    }
+
+    for my $SysConfig ( @{ $Param{DisableSysConfigs} } ) {
+        $Self->ConfigSettingChange(
+            Valid => 0,
+            Key   => $SysConfig,
+        );
+    }
+
+    return 1;
+}
+
 =head2 ProvideTestDatabase()
 
 Provide temporary database for the test. Please first define test database settings in C<Config.pm>, i.e:
@@ -884,11 +1021,11 @@ receive all calls sent over system C<DBObject>.
 All database contents will be automatically dropped when the Helper object is destroyed.
 
     $HelperObject->ProvideTestDatabase(
-        DatabaseXMLString => $XML,      # (optional) OTRS database XML schema to execute
+        DatabaseXMLString => $XML,      # (optional) database XML schema to execute
                                         # or
         DatabaseXMLFiles => [           # (optional) List of XML files to load and execute
-            '/opt/otrs/scripts/database/otrs-schema.xml',
-            '/opt/otrs/scripts/database/otrs-initial_insert.xml',
+            '/opt/znuny/scripts/database/schema.xml',
+            '/opt/znuny/scripts/database/initial_insert.xml',
         ],
     );
 
